[Pkg-owncloud-commits] [owncloud-client] 132/333: Properly abort if QtKeychain is not found

Sandro Knauß hefee-guest at moszumanska.debian.org
Thu Apr 17 23:16:44 UTC 2014


This is an automated email from the git hooks/post-receive script.

hefee-guest pushed a commit to branch master
in repository owncloud-client.

commit 28cf9ce1a4df167d22b483466ebba866e7f5ad92
Author: Daniel Molkentin <danimo at owncloud.com>
Date:   Wed Mar 12 17:55:30 2014 +0100

    Properly abort if QtKeychain is not found
    
    Fixes #1486
---
 cmake/modules/FindQtKeychain.cmake | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/cmake/modules/FindQtKeychain.cmake b/cmake/modules/FindQtKeychain.cmake
index d3d221b..a0c81be 100644
--- a/cmake/modules/FindQtKeychain.cmake
+++ b/cmake/modules/FindQtKeychain.cmake
@@ -1,8 +1,8 @@
 # - Try to find QtKeyChain
 # Once done this will define
 #  QTKEYCHAIN_FOUND - System has QtKeyChain
 #  QTKEYCHAIN_INCLUDE_DIRS - The QtKeyChain include directories
 #  QTKEYCHAIN_LIBRARIES - The libraries needed to use QtKeyChain
 #  QTKEYCHAIN_DEFINITIONS - Compiler switches required for using LibXml2
 
 find_path(QTKEYCHAIN_INCLUDE_DIR qtkeychain/keychain.h)
@@ -12,7 +12,7 @@ find_library(QTKEYCHAIN_LIBRARY NAMES libqtkeychain qtkeychain)
 include(FindPackageHandleStandardArgs)
 # handle the QUIETLY and REQUIRED arguments and set QTKEYCHAIN_FOUND to TRUE
 # if all listed variables are TRUE
-find_package_handle_standard_args(QtKeyChain  DEFAULT_MSG
+find_package_handle_standard_args(QtKeychain  DEFAULT_MSG
 	QTKEYCHAIN_LIBRARY QTKEYCHAIN_INCLUDE_DIR)
 
 mark_as_advanced(QTKEYCHAIN_INCLUDE_DIR QTKEYCHAIN_LIBRARY )
@@ -1,8 +1,8 @@
-# - Try to find QtKeyChain
+# - Try to find QtKeychain
 # Once done this will define
@@ -1,8 +1,8 @@
 # Once done this will define
-#  QTKEYCHAIN_FOUND - System has QtKeyChain
-#  QTKEYCHAIN_INCLUDE_DIRS - The QtKeyChain include directories
-#  QTKEYCHAIN_LIBRARIES - The libraries needed to use QtKeyChain
+#  QTKEYCHAIN_FOUND - System has QtKeychain
+#  QTKEYCHAIN_INCLUDE_DIRS - The QtKeychain include directories
+#  QTKEYCHAIN_LIBRARIES - The libraries needed to use QtKeychain
 #  QTKEYCHAIN_DEFINITIONS - Compiler switches required for using LibXml2
 

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-owncloud/owncloud-client.git



More information about the Pkg-owncloud-commits mailing list